==> open-cluster-management-apps-model-6.1.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/SubscriptionPerClusterStatusFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SubscriptionPerClusterStatusFluentImpl<A extends SubscriptionPerClusterStatusFluent<A>> extends BaseFluent<A> implements SubscriptionPerClusterStatusFluent<A>{
  public SubscriptionPerClusterStatusFluentImpl() {
  }
  public SubscriptionPerClusterStatusFluentImpl(SubscriptionPerClusterStatus instance) {
    this.withPackages(instance.getPackages()); 
  }
  private Map<String,SubscriptionUnitStatus> packages;
  public A addToPackages(String key,SubscriptionUnitStatus value) {
    if(this.packages == null && key != null && value != null) { this.packages = new LinkedHashMap(); }
    if(key != null && value != null) {this.packages.put(key, value);} return (A)this;
  }
  public A addToPackages(Map<String,SubscriptionUnitStatus> map) {
    if(this.packages == null && map != null) { this.packages = new LinkedHashMap(); }
    if(map != null) { this.packages.putAll(map);} return (A)this;
  }
  public A removeFromPackages(String key) {
    if(this.packages == null) { return (A) this; }
    if(key != null && this.packages != null) {this.packages.remove(key);} return (A)this;
  }
  public A removeFromPackages(Map<String,SubscriptionUnitStatus> map) {
    if(this.packages == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.packages != null){this.packages.remove(key);}}} return (A)this;
  }
  public Map<String,SubscriptionUnitStatus> getPackages() {
    return this.packages;
  }
  public <K,V>A withPackages(Map<String,SubscriptionUnitStatus> packages) {
    if (packages == null) { this.packages =  null;} else {this.packages = new LinkedHashMap(packages);} return (A) this;
  }
  public Boolean hasPackages() {
    return this.packages != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SubscriptionPerClusterStatusFluentImpl that = (SubscriptionPerClusterStatusFluentImpl) o;
    if (packages != null ? !packages.equals(that.packages) :that.packages != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(packages,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (packages != null && !packages.isEmpty()) { sb.append("packages:"); sb.append(packages); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-apps-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/SubscriptionPerClusterStatusFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SubscriptionPerClusterStatusFluentImpl<A extends SubscriptionPerClusterStatusFluent<A>> extends BaseFluent<A> implements SubscriptionPerClusterStatusFluent<A>{
  public SubscriptionPerClusterStatusFluentImpl() {
  }
  public SubscriptionPerClusterStatusFluentImpl(SubscriptionPerClusterStatus instance) {
    if (instance != null) {
      this.withPackages(instance.getPackages());
    }
  }
  private Map<String,SubscriptionUnitStatus> packages;
  public A addToPackages(String key,SubscriptionUnitStatus value) {
    if(this.packages == null && key != null && value != null) { this.packages = new LinkedHashMap(); }
    if(key != null && value != null) {this.packages.put(key, value);} return (A)this;
  }
  public A addToPackages(Map<String,SubscriptionUnitStatus> map) {
    if(this.packages == null && map != null) { this.packages = new LinkedHashMap(); }
    if(map != null) { this.packages.putAll(map);} return (A)this;
  }
  public A removeFromPackages(String key) {
    if(this.packages == null) { return (A) this; }
    if(key != null && this.packages != null) {this.packages.remove(key);} return (A)this;
  }
  public A removeFromPackages(Map<String,SubscriptionUnitStatus> map) {
    if(this.packages == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.packages != null){this.packages.remove(key);}}} return (A)this;
  }
  public Map<String,SubscriptionUnitStatus> getPackages() {
    return this.packages;
  }
  public <K,V>A withPackages(Map<String,SubscriptionUnitStatus> packages) {
    if (packages == null) { this.packages =  null;} else {this.packages = new LinkedHashMap(packages);} return (A) this;
  }
  public Boolean hasPackages() {
    return this.packages != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubscriptionPerClusterStatusFluentImpl that = (SubscriptionPerClusterStatusFluentImpl) o;
    if (!java.util.Objects.equals(packages, that.packages)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(packages,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (packages != null && !packages.isEmpty()) { sb.append("packages:"); sb.append(packages); }
    sb.append("}");
    return sb.toString();
  }
  
}
